@@ -12,19 +12,24 @@ from lutris import settings
 LIBRETRO_CORES = [
     ('4do (3DO)', '4do', '3DO'),
     ('atari800 (Atari 800/5200)', 'atari800', 'Atari 800/5200'),
-    ('blueMSX (MSX/MSX2/MSX+)', 'bluemsx', 'MSX/MSX2/MSX+'),
+    ('blueMSX (MSX/MSX2/MSX2+)', 'bluemsx', 'MSX/MSX2/MSX2+'),
     ('Caprice32 (Amstrad CPC)', 'cap32', 'Amstrad CPC'),
     ('ChaiLove', 'chailove', 'ChaiLove'),
     ('Citra (Nintendo 3DS)', 'citra', 'Nintendo 3DS'),
     ('Citra Canary (Nintendo 3DS)', 'citra_canary', 'Nintendo 3DS'),
     ('CrocoDS (Amstrad CPC)', 'crocods', 'Amstrad CPC'),
+    ('Daphne (Arcade)', 'daphne', 'Arcade'),
     ('DesmuME (Nintendo DS)', 'desmume', 'Nintendo DS'),
     ('Dolphin (Nintendo Wii/Gamecube)', 'dolphin', 'Nintendo Wii/Gamecube'),
     ('EightyOne (Sinclair ZX81)', '81', 'Sinclair ZX81'),
+    ('FB Alpha (Arcade)', 'fbalpha', 'Arcade'),
     ('FCEUmm (Nintendo Entertainment System)', 'fceumm', 'Nintendo NES'),
     ('fMSX (MSX/MSX2/MSX2+)', 'fmsx', 'MSX/MSX2/MSX2+'),
+    ('FreeJ2ME (J2ME)', 'freej2me', 'J2ME'),
     ('Fuse (ZX Spectrum)', 'fuse', 'Sinclair ZX Spectrum'),
     ('Gambatte (Game Boy Color)', 'gambatte', 'Nintendo Game Boy Color'),
+    ('Gearboy (Game Boy Color)', 'gearboy', 'Nintendo Game Boy Color'),
+    ('Gearsystem (Sega Maste System/Gamegear)', 'gearsystem', 'Sega Maste System/Gamegear'),
     ('Genesis Plus GX (Sega Genesis)', 'genesis_plus_gx', 'Sega Genesis'),
     ('Handy (Atari Lynx)', 'handy', 'Atari Lynx'),
     ('Hatari (Atari ST/STE/TT/Falcon)', 'hatari', 'Atari ST/STE/TT/Falcon'),
@@ -47,6 +52,7 @@ LIBRETRO_CORES = [
     ('Neko Project 2 (NEC PC-98)', 'nekop2', 'NEC PC-98'),
     ('Neko Project II kai (NEC PC-98)', 'np2kai', 'NEC PC-98'),
     ('O2EM (Magnavox Odyssey²)', 'o2em', 'Magnavox Odyssey²'),
+    ('ParaLLEl N64 (Nintendo 64)', 'parallel_n64', 'Nintendo N64'),
     ('PCSX Rearmed (Sony Playstation)', 'pcsx_rearmed', 'Sony PlayStation'),
     ('PicoDrive (Sega Genesis)', 'picodrive', 'Sega Genesis'),
     ('Portable SHARP X68000 Emulator (SHARP X68000)', 'px68k', 'Sharp X68000'),
@@ -55,7 +61,9 @@ LIBRETRO_CORES = [
     ('Redream (Sega Dreamcast)', 'redream', 'Sega Dreamcast'),
     ('Reicast (Sega Dreamcast)', 'reicast', 'Sega Dreamcast'),
     ('Snes9x (Super Nintendo)', 'snes9x', 'Nintendo SNES'),
+    ('Snes9x2010 (Super Nintendo)', 'snes9x2010', 'Nintendo SNES'),
     ('Stella (Atari 2600)', 'stella', 'Atari 2600'),
+    ('Uzem (Uzebox)', 'uzem', 'Uzebox'),
     ('VecX (Vectrex)', 'vecx', 'Vectrex'),
     ('Yabause (Sega Saturn)', 'yabause', 'Sega Saturn'),
     ('VBA Next (Game Boy Advance)', 'vba_next', 'Nintendo Game Boy Advance'),
@@ -71,22 +79,8 @@ LIBRETRO_CORES = [
 def get_core_choices():
     return [(core[0], core[1]) for core in LIBRETRO_CORES]
 
-
-def get_default_config_path():
-    return os.path.join(settings.RUNNER_DIR, 'retroarch/retroarch.cfg')
-
-
-def get_default_assets_directory():
-    return os.path.join(settings.RUNNER_DIR, 'retroarch/assets')
-
-
-def get_default_cores_directory():
-    return os.path.join(settings.RUNNER_DIR, 'retroarch/cores')
-
-
-def get_default_info_directory():
-    return os.path.join(settings.RUNNER_DIR, 'retroarch/info')
-
+def get_default_config_path(path=''):
+    return os.path.join(settings.RUNNER_DIR, 'retroarch', path)
 
 class libretro(Runner):
     human_name = "Libretro"
@@ -119,7 +113,7 @@ class libretro(Runner):
             'option': 'config_file',
             'type': 'file',
             'label': 'Config file',
-            'default': get_default_config_path()
+            'default': get_default_config_path('retroarch.cfg')
         }
     ]
 
@@ -169,39 +163,52 @@ class libretro(Runner):
             super(libretro, self).install(version, downloader, callback)
 
     def get_run_data(self):
-        self.prelaunch()
         return {
             'command': [self.get_executable()] + self.get_runner_parameters()
         }
 
     def get_config_file(self):
-        return self.runner_config.get('config_file') or get_default_config_path()
+        return self.runner_config.get('config_file') or get_default_config_path('retroarch.cfg')
 
     def get_system_directory(self, retro_config):
         """Return the system directory used for storing BIOS and firmwares."""
         system_directory = retro_config['system_directory']
         if not system_directory or system_directory == 'default':
-            system_directory = '~/.config/retroarch/system'
+            system_directory = get_default_config_path('system')
         return os.path.expanduser(system_directory)
 
     def prelaunch(self):
         config_file = self.get_config_file()
+
+        # Create retroarch.cfg if it doesn't exist.
         if not os.path.exists(config_file):
-            logger.warning("Unable to find retroarch config. Except erratic behavior")
-            return True
-        retro_config = RetroConfig(config_file)
+            f = open(config_file, 'w')
+            f.write('# Lutris RetroArch Configuration')
+            f.close()
 
-        retro_config['libretro_directory'] = get_default_cores_directory()
-        retro_config['libretro_info_path'] = get_default_info_directory()
-
-        # Change assets path to the Lutris provided one if necessary
-        assets_directory = os.path.expanduser(retro_config['assets_directory'])
-        if system.path_is_empty(assets_directory):
-            retro_config['assets_directory'] = get_default_assets_directory()
-        retro_config.save()
+            # Build the default config settings.
+            retro_config = RetroConfig(config_file)
+            retro_config['libretro_directory'] = get_default_config_path('cores')
+            retro_config['libretro_info_path'] = get_default_config_path('info')
+            retro_config['content_database_path'] = get_default_config_path('database/rdb')
+            retro_config['cheat_database_path'] = get_default_config_path('database/cht')
+            retro_config['cursor_directory'] = get_default_config_path('database/cursors')
+            retro_config['screenshot_directory'] = get_default_config_path('screenshots')
+            retro_config['input_remapping_directory'] = get_default_config_path('remaps')
+            retro_config['video_shader_dir'] = get_default_config_path('shaders')
+            retro_config['core_assets_directory'] = get_default_config_path('downloads')
+            retro_config['thumbnails_directory'] = get_default_config_path('thumbnails')
+            retro_config['playlist_directory'] = get_default_config_path('playlists')
+            retro_config['joypad_autoconfig_dir'] = get_default_config_path('autoconfig')
+            retro_config['rgui_config_directory'] = get_default_config_path('config')
+            retro_config['overlay_directory'] = get_default_config_path('overlay')
+            retro_config['assets_directory'] = get_default_config_path('assets')
+            retro_config.save()
+        else:
+            retro_config = RetroConfig(config_file)
 
         core = self.game_config.get('core')
-        info_file = os.path.join(get_default_info_directory(),
+        info_file = os.path.join(get_default_config_path('info'),
                                  '{}_libretro.info'.format(core))
         if os.path.exists(info_file):
             core_config = RetroConfig(info_file)
