@@ -252,12 +252,16 @@ def wineexec(executable, args="", wine_path=None, prefix=None, arch=None,
         wineenv['WINEPREFIX'] = prefix
 
     wine_config = config or LutrisConfig(runner_slug='wine')
-
-    if use_lutris_runtime(
-            wine_path=wineenv['WINE'],
-            force_disable=disable_runtime or wine_config.system_config['disable_runtime']
-    ):
-        wineenv['LD_LIBRARY_PATH'] = ':'.join(runtime.get_paths())
+    disable_runtime = disable_runtime or wine_config.system_config['disable_runtime']
+    if use_lutris_runtime(wine_path=wineenv['WINE'], force_disable=disable_runtime):
+        if WINE_DIR in wine_path:
+            wine_root_path = os.path.dirname(os.path.dirname(wine_path))
+        else:
+            wine_root_path = None
+        wineenv['LD_LIBRARY_PATH'] = ':'.join(runtime.get_paths(
+            prefer_system_libs=wine_config.system_config['prefer_system_libs'],
+            wine_path=wine_root_path
+        ))
 
     if overrides:
         wineenv['WINEDLLOVERRIDES'] = get_overrides_env(overrides)
@@ -281,7 +285,10 @@ def wineexec(executable, args="", wine_path=None, prefix=None, arch=None,
 def winetricks(app, prefix=None, arch=None, silent=True,
                wine_path=None, config=None, disable_runtime=False):
     """Execute winetricks."""
-    winetricks_path = os.path.join(datapath.get(), 'bin/winetricks')
+    winetricks_path = os.path.join(settings.RUNTIME_DIR, 'winetricks/winetricks')
+    if not system.path_exists(winetricks_path):
+        logger.warning("Could not find local winetricks install, falling back to bundled version")
+        winetricks_path = os.path.join(datapath.get(), 'bin/winetricks')
     if wine_path:
         winetricks_wine = wine_path
     else:
@@ -342,16 +349,17 @@ def detect_prefix_arch(prefix_path=None):
     registry_path = os.path.join(prefix_path, 'system.reg')
     if not os.path.isdir(prefix_path) or not os.path.isfile(registry_path):
         # No prefix_path exists or invalid prefix
-        logger.debug("Not detecting prefix arch, no prefix found in %s", prefix_path)
-        return
+        logger.debug("Prefix not found: %s", prefix_path)
+        return None
     with open(registry_path, 'r') as registry:
-        for i in range(5):
+        for _line_no in range(5):
             line = registry.readline()
             if 'win64' in line:
                 return 'win64'
             elif 'win32' in line:
                 return 'win32'
-    logger.debug("Can't detect prefix arch for %s", prefix_path)
+    logger.debug("Failed to detect Wine prefix architecture in %s", prefix_path)
+    return None
 
 
 def set_drive_path(prefix, letter, path):
@@ -371,21 +379,26 @@ def use_lutris_runtime(wine_path, force_disable=False):
     automatically if Wine is installed system wide.
     """
     if force_disable or runtime.RUNTIME_DISABLED:
+        logger.info("Runtime is forced disabled")
         return False
     if WINE_DIR in wine_path:
         logger.debug("%s is provided by Lutris, using runtime")
         return True
-    return not is_installed_systemwide()
+    if is_installed_systemwide():
+        logger.info("Using system wine version, not using runtime")
+        return False
+    logger.debug("Using Lutris runtime for wine")
+    return True
 
 
 def is_installed_systemwide():
     """Return whether Wine is installed outside of Lutris"""
-    for build in WINE_PATHS.keys():
-        if system.find_executable(WINE_PATHS[build]):
+    for build in WINE_PATHS.values():
+        if system.find_executable(build):
             if (
-                WINE_PATHS[build] == 'wine' and
-                os.path.exists('/usr/lib/wine/wine64') and
-                not os.path.exists('/usr/lib/wine/wine')
+                    build == 'wine' and
+                    os.path.exists('/usr/lib/wine/wine64') and
+                    not os.path.exists('/usr/lib/wine/wine')
             ):
                 logger.warning("wine32 is missing from system")
                 return False
@@ -531,16 +544,10 @@ class wine(Runner):
         }
     ]
 
-    system_options_override = [
-        {
-            'option': 'disable_runtime',
-            'default': is_installed_systemwide(),
-        }
-    ]
-
     reg_prefix = "HKEY_CURRENT_USER/Software/Wine"
     reg_keys = {
         "RenderTargetLockMode": r"%s/Direct3D" % reg_prefix,
+        "Audio": r"%s/Drivers" % reg_prefix,
         "MouseWarpOverride": r"%s/DirectInput" % reg_prefix,
         "OffscreenRenderingMode": r"%s/Direct3D" % reg_prefix,
         "StrictDrawOrdering": r"%s/Direct3D" % reg_prefix,
@@ -772,6 +779,19 @@ class wine(Runner):
                     'Set this to "Y" to allow wine switch the resolution using XVidMode extension.'
                 )
             },
+            {
+                'option': 'Audio',
+                'label': 'Audio driver',
+                'type': 'choice',
+                'choices': [('Auto', 'auto'),
+                            ('ALSA', 'alsa'),
+                            ('PulseAudio', 'pulse'),
+                            ('OSS', 'oss')],
+                'default': 'auto',
+                'help': ("Which audio backend to use.\n"
+                         "By default, Wine automatically picks the right one "
+                         "for your system.")
+            },
             {
                 'option': 'ShowCrashDialog',
                 'label': 'Show crash dialogs',
@@ -927,19 +947,24 @@ class wine(Runner):
         filename = dlg.filename
         if not filename:
             return
+        self.prelaunch()
         wineexec(filename, wine_path=self.get_executable(), prefix=self.prefix_path, config=self)
 
     def run_winecfg(self, *args):
+        self.prelaunch()
         winecfg(wine_path=self.get_executable(), prefix=self.prefix_path,
                 arch=self.wine_arch, config=self)
 
     def run_regedit(self, *args):
+        self.prelaunch()
         wineexec("regedit", wine_path=self.get_executable(), prefix=self.prefix_path, config=self)
 
     def run_winetricks(self, *args):
+        self.prelaunch()
         winetricks('', prefix=self.prefix_path, wine_path=self.get_executable(), config=self)
 
     def run_joycpl(self, *args):
+        self.prelaunch()
         joycpl(prefix=self.prefix_path, wine_path=self.get_executable(), config=self)
 
     def set_wine_desktop(self, enable_desktop=False):
@@ -1020,7 +1045,8 @@ class wine(Runner):
     def get_env(self, os_env=True):
         """Return environment variables used by the game"""
         # Always false to runner.get_env, the default value
-        # of os_env is inverted in that class.
+        # of os_env is inverted in the wine class,
+        # the OS env is read later.
         env = super(wine, self).get_env(False)
         if os_env:
             env.update(os.environ.copy())
@@ -1035,6 +1061,18 @@ class wine(Runner):
             env['WINEDLLOVERRIDES'] = get_overrides_env(overrides)
         return env
 
+    def get_runtime_env(self):
+        """Return runtime environment variables with path to wine for Lutris builds"""
+        wine_path = self.get_executable()
+        if WINE_DIR in wine_path:
+            wine_root = os.path.dirname(os.path.dirname(wine_path))
+        else:
+            wine_root = None
+        return runtime.get_env(
+            self.system_config.get('prefer_system_libs', True),
+            wine_path=wine_root
+        )
+
     def get_pids(self, wine_path=None):
         """Return a list of pids of processes using the current wine exe."""
         if wine_path:
