@@ -24,6 +24,7 @@ create_prefix = wine.create_prefix
 wineexec = wine.wineexec
 winetricks = wine.winetricks
 winecfg = wine.winecfg
+winekill = wine.winekill
 
 STEAM_INSTALLER_URL = "http://lutris.net/files/runners/SteamInstall.msi"
 
@@ -199,7 +200,7 @@ class winesteam(wine.wine):
         """Return the working directory to use when running the game."""
         if self.runner_config['run_without_steam']:
             steamless_binary = self.game_config.get('steamless_binary')
-            if (os.path.isfile(steamless_binary)):
+            if steamless_binary and os.path.isfile(steamless_binary):
                 return os.path.dirname(steamless_binary)
         return os.path.expanduser("~/")
 
