@@ -2,12 +2,12 @@ import re
 import time
 import subprocess
 
-from lutris.util.system import find_executable
+from lutris.util import system
 from lutris.util.log import logger
 
 XRANDR_CACHE = None
 XRANDR_CACHE_SET_AT = None
-XGAMMA_FOUND = False
+XGAMMA_FOUND = None
 
 
 def cached(function):
@@ -148,7 +148,7 @@ def restore_gamma():
     """Restores gamma to a normal level."""
     global XGAMMA_FOUND
     if XGAMMA_FOUND is None:
-        XGAMMA_FOUND = find_executable('xgamma')
+        XGAMMA_FOUND = bool(system.find_executable('xgamma'))
     if XGAMMA_FOUND is True:
         subprocess.Popen(["xgamma", "-gamma", "1.0"])
     else:
